<?php 

/*
 * login.php
 * For servers whose auth_type is set to 'form' or 'http'. Pass me the login info
 * and I'll write two cookies, pla_login_dn_X and pla_pass_X
 * where X is the server_id. The cookie_time comes from config.php
 *
 * Note: this file uses ldap_connect() and ldap_bind() only for purposes
 *       of verifying the user-supplied DN and Password.
 *
 * Variables that come in as POST vars:
 *  - login_dn
 *  - login_pass 
 *  - server_id
 */

require 'common.php';

$server_id = $_POST['server_id'];
$dn = isset( $_POST['login_dn'] ) ? $_POST['login_dn'] : null;
$uid = isset( $_POST['uid'] ) ? $_POST['uid'] : null;
$pass = isset( $_POST['login_pass'] ) ? $_POST['login_pass'] : null;
$redirect = isset( $_POST['redirect'] ) ? rawurldecode( $_POST['redirect'] ) : null;
$anon_bind = isset( $_POST['anonymous_bind'] ) && $_POST['anonymous_bind'] == 'on' ? true : false;
check_server_id( $server_id ) or pla_error( $lang['bad_server_id'] );

if( ! $anon_bind ) {
	strlen($pass) or pla_error( $lang['password_blank'] );
}

if( $anon_bind ) {
	$dn = null;
	$pass = null;
}

$host = $servers[$server_id]['host'];
$port = $servers[$server_id]['port'];

// Checks if the logni_attr option is enabled for this host,
// which allows users to login with a simple username like 'jdoe' rather
// than the fully qualified DN, 'uid=jdoe,ou=people,,dc=example,dc=com'.
// We don't do this, of course, for anonymous binds.
if ( login_attr_enabled( $server_id ) && ! $anon_bind ) {

	// search for the "uid" first
	$ds = ldap_connect ( $host, $port );
	$ds or pla_error( $lang['could_not_connect'] );
	@ldap_set_option( $ds, LDAP_OPT_PROTOCOL_VERSION, 3 );
	// try to fire up TLS if specified in the config
    if( tls_enabled( $server_id ) ) {
		function_exists( 'ldap_start_tls' ) or pla_error( $lang['php_install_not_supports_tls'] );
		@ldap_start_tls( $ds ) or pla_error( $lang['could_not_start_tls'], ldap_error( $ds ), ldap_errno( $ds ) );
	}
	@ldap_bind ($ds) or pla_error( $lang['could_not_bind_anon'] . ' ' . $lang['anon_bind-required_for_login_attr'] );
	$search_base = isset( $servers[$server_id]['base'] ) && '' != trim( $servers[$server_id]['base'] ) ?
		$servers[$server_id]['base'] :
		try_to_get_root_dn( $server_id );
	$sr = @ldap_search($ds,$search_base,$servers[$server_id]['login_attr'] ."=". $uid, array("dn"), 0, 1);
	$result = @ldap_get_entries($ds,$sr);
	$dn = isset( $result[0]['dn'] ) ? $result[0]['dn'] : false;
	@ldap_unbind( $ds );
	if( false === $dn )
		pla_error( sprintf( $lang['could_not_find_user'], htmlspecialchars( $uid ) ) );
}

// verify that the login is good 
$ds = @ldap_connect( $host, $port );
$ds or pla_error( sprintf( $lang['could_not_connect_to_host_on_port'], htmlspecialchars( $host ),  htmlspecialchars( $port ) ) );

// go with LDAP version 3 if possible 
@ldap_set_option( $ds, LDAP_OPT_PROTOCOL_VERSION, 3 );
if( tls_enabled( $server_id ) ) {
    function_exists( 'ldap_start_tls' ) or pla_error( $lang['php_install_not_supports_tls'] );
    ldap_start_tls( $ds ) or pla_error( $lang['could_not_start_tls'], ldap_error( $ds ), ldap_errno( $ds ) );
}

if( $anon_bind )
	$bind_result = @ldap_bind( $ds );
else
	$bind_result = @ldap_bind( $ds, $dn, $pass );

if( ! $bind_result ) {
	if( $anon_bind )
		pla_error( $lang['could_not_bind_anon'], ldap_error( $ds ), ldap_errno( $ds ) );
	else
		pla_error( $lang['bad_user_name_or_password'] );
} 

set_cookie_login_dn( $server_id, $dn, $pass, $anon_bind ) or pla_error( $lang['could_not_set_cookie'] );

// Clear out any pre-existing tree data in the session for this server
pla_session_start();
if( session_is_registered( 'tree' ) )
	if( isset( $_SESSION['tree'][$server_id] ) )
		unset( $_SESSION['tree'][$server_id] );
if( session_is_registered( 'tree_icons' ) )
	if( isset( $_SESSION['tree_icons'][$server_id] ) )
		unset( $_SESSION['tree_icons'][$server_id] );
session_write_close();

include realpath( 'header.php' );
?>

<script language="javascript">
	<?php if( $anon_bind && anon_bind_tree_disabled() )  { ?>
	
		parent.location.href='search.php?server_id=<?php echo $server_id; ?>'

	<?php } else {  ?>

		parent.left_frame.location.reload();

		<?php if ( $redirect ) { ?>

			location.href='<?php echo $redirect; ?>';

		<?php } ?>

	<?php } ?>
</script>
<link rel="stylesheet" href="style.css" />

<?php if( $redirect ) { ?>

	<meta http-equiv="refresh" content="0;<?php echo $redirect; ?>" />

<?php } ?>

</head>
<body>

<?php if( $redirect ) { ?>

	<a href="<?php echo $redirect; ?>"><?php echo $lang['redirecting_click_if_nothing_happens']; ?></a><br />

<?php } else { ?>

	<center>
	<br />
	<br />
	<br />
		<?php echo sprintf( $lang['successfully_logged_in_to_server'], 
					htmlspecialchars( $servers[$server_id]['name'] ) ); ?><br />
	<?php if( $anon_bind ) { ?>
		(<?php echo $lang['anonymous_bind']; ?>)	
	<?php } ?>
	<br />
	</center>

<?php } ?>

</body>
</html>

